=======
History
=======

0.5.0 (2020-08-18)
------------------
* Remove mock responses that included stage names.


0.5.0 (2020-08-18)
------------------
* Remove `passed` from resource.
* Remove `srs_stage_name` from assignments and reviews

0.4.0 (2020-04-30)
------------------
* Add Preferences to User Information
* Add Subscription to User Information

0.3.0 (2019-11-09)
------------------
* Add `auxiliary_meanings` to Subject

0.2.1 (2019-11-05)
------------------
* Fix crash caused by WK removing a field from their API.

0.1.1 (2018-06-26)
------------------

* Change Assignment endpoint to reflect the newly dropped fields from the api (`level` specifically).
* Add some proper String representation
* Work on the Etag cache, bringing it closer to completion.

0.1.0 (2018-06-26)
------------------

* First release on PyPI.
